PeamanReferenceHelper class

Constructors

PeamanReferenceHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

chatsCol → ColRef
no setter
feedsCol → ColRef
no setter
hashtagsCol → ColRef
no setter
momentsCol → ColRef
no setter
usersCol → ColRef
no setter

Static Methods

blockedByUsersCol({required String uid}) → ColRef
blockedUsersCol({required String uid}) → ColRef
chatDoc({required String chatId}) → DocRef
chatFilesCol({required String chatId}) → ColRef
commentedFeedsCol({required String uid}) → ColRef
commentsCol({required String feedId}) → ColRef
devicesCol({required String uid}) → ColRef
feedCommentersCol({required String feedId}) → ColRef
feedDoc({required String feedId}) → DocRef
feedFollowersCol({required String feedId}) → ColRef
feedReactorsCol({required String feedId}) → ColRef
feedRepliersCol({required String feedId}) → ColRef
feedSaversCol({required String feedId}) → ColRef
feedViewersCol({required String feedId}) → ColRef
followedFeedsCol({required String uid}) → ColRef
hashtagDoc({required String hashtag}) → DocRef
hashtagFeedsCol({required String hashtag}) → ColRef
messagesCol({required String chatId}) → ColRef
momentDoc({required String momentId}) → DocRef
momentViewersCol({required String momentId}) → ColRef
myFeedsCol({required String uid}) → ColRef
notificationsCol({required String uid}) → ColRef
reactedFeedsCol({required String uid}) → ColRef
reactionsCol({required String feedId}) → ColRef
receivedFollowRequestsCol({required String uid}) → ColRef
repliedFeedsCol({required String uid}) → ColRef
savedFeedsCol({required String uid}) → ColRef
sentFollowRequestsCol({required String uid}) → ColRef
userDoc({required String uid}) → DocRef
userFollowersCol({required String uid}) → ColRef
userFollowingsCol({required String uid}) → ColRef
viewedFeedsCol({required String uid}) → ColRef