PeamanChatFile class

Constructors

PeamanChatFile({String? id, List<PeamanFileUrl> urls = const [], int? createdAt, int? updatedAt})

Properties

createdAt → int?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → int?
final
urls → List<PeamanFileUrl>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> data) → PeamanChatFile