IdUser class

Implementers

Constructors

IdUser({required String? uid, required int? createdAt, required int? updatedAt, Map<String, dynamic> extraData = const <String, dynamic>{}})

Properties

createdAt → int?
final
extraData → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid → String?
final
updatedAt → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> data) → IdUser