PeamanMessage class

Constructors

PeamanMessage({String? id, String? chatId, String? text, List<PeamanFileUrl> files = const [], String? senderId, PeamanMessageType type = PeamanMessageType.text, List<String> receiverIds = const <String>[], String? extraId, int? createdAt, int? updatedAt, bool visibility = true, Map<String, dynamic> extraData = const {}})

Properties

chatId → String?
final
createdAt → int?
final
extraData → Map<String, dynamic>
final
extraId → String?
final
files → List<PeamanFileUrl>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
receiverIds → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderId → String?
final
text → String?
final
type → PeamanMessageType
final
updatedAt → int?
final
visibility → bool
final

Methods

copyWith({String? id, String? chatId, String? text, String? senderId, List<String>? receiverId, String? extraId, List<PeamanFileUrl>? files, PeamanMessageType? type, int? createdAt, int? updatedAt, bool? visibility, Map<String, dynamic>? extraData}) → PeamanMessage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> data) → PeamanMessage