PeamanNotification class

Constructors

PeamanNotification({String? id, String? senderId, String? receiverId, String title = '', String body = '', bool read = false, int? createdAt, int? updatedAt, bool visibility = true, Map<String, dynamic> extraData = const {}})

Properties

body → String
final
createdAt → int?
final
extraData → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
read → bool
final
receiverId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderId → String?
final
title → String
final
updatedAt → int?
final
visibility → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> data) → PeamanNotification