PeamanUser class

Constructors

PeamanUser({String? uid, String? name, String? userName, String? email, String? photo, String? phone, String? country, String? bio, PeamanGender gender = PeamanGender.unknown, int? dob, String? profession, int feeds = 0, int photos = 0, int videos = 0, PeamanOnlineStatus onlineStatus = PeamanOnlineStatus.away, int? lastOnlineAt, List<String> searchKeys = const [], int followers = 0, int following = 0, int reactionsReceivedFromFeeds = 0, int commentsReceivedFromFeeds = 0, int repliesReceivedFromFeeds = 0, int sharesReceivedFromFeeds = 0, int viewsReceivedFromFeeds = 0, bool admin = false, bool editor = false, bool tester = false, int onboardingStep = 0, bool onboardingCompleted = false, double? latitude, double? longitude, int? createdAt, bool visibility = true, Map<String, dynamic> extraData = const {}})

Properties

admin → bool
final
bio → String?
final
commentsReceivedFromFeeds → int
final
country → String?
final
createdAt → int?
final
dob → int?
final
editor → bool
final
email → String?
final
extraData → Map<String, dynamic>
final
feeds → int
final
followers → int
final
following → int
final
gender → PeamanGender
final
hashCode → int
The hash code for this object.
no setterinherited
lastOnlineAt → int?
final
latitude → double?
final
longitude → double?
final
name → String?
final
onboardingCompleted → bool
final
onboardingStep → int
final
onlineStatus → PeamanOnlineStatus
final
phone → String?
final
photo → String?
final
photos → int
final
profession → String?
final
reactionsReceivedFromFeeds → int
final
repliesReceivedFromFeeds → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchKeys → List<String>
final
sharesReceivedFromFeeds → int
final
tester → bool
final
uid → String?
final
userName → String?
final
videos → int
final
viewsReceivedFromFeeds → int
final
visibility → bool
final

Methods

copyWith({String? uid, String? name, String? userName, String? email, String? photo, String? phone, String? country, String? bio, PeamanGender? gender, int? dob, String? profession, String? profileStatus, PeamanOnlineStatus? onlineStatus, int? lastOnlineAt, int? feeds, int? photos, int? videos, int? followers, int? following, List<String>? searchKeys, int? reactionsReceivedFromFeeds, int? commentsReceivedFromFeeds, int? repliesReceivedFromFeeds, int? sharesReceivedFromFeeds, int? viewsReceivedFromFeeds, bool? admin, bool? editor, bool? tester, int? onboardingStep, bool? onboardingCompleted, int? createdAt, double? latitude, double? longitude, bool? visibility, Map<String, dynamic>? extraData}) → PeamanUser
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> data) → PeamanUser